==> proc-10.1.25.tar.gz: proc/src/Plugin/Field/FieldFormatter/ProcFieldFormatter.php <==
<?php

namespace Drupal\proc\Plugin\Field\FieldFormatter;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\EntityReferenceLabelFormatter;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'entity reference label' formatter.
 *
 * @FieldFormatter(
 *   id = "proc_entity_reference_label_formatter",
 *   label = @Translation("Label"),
 *   description = @Translation("Display the label of the referenced proc entities."),
 *   field_types = {
 *     "proc_entity_reference_field"
 *   }
 * )
 */
class ProcFieldFormatter extends EntityReferenceLabelFormatter {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'decrypt' => FALSE,
      'new_tab' => TRUE,
      'modal' => FALSE,
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $elements = parent::settingsForm($form, $form_state);

    $elements['new_tab'] = [
      '#title' => $this->t('Open in a new tab'),
      '#type' => 'checkbox',
      '#default_value' => $this->getSetting('new_tab'),
      '#states' => [
        'visible' => [
          ':input[name="fields[field_encrypted_attachment][settings_edit_form][settings][link]"]' => ['checked' => TRUE],
        ],
        'disabled' => [
          ':input[name="fields[field_encrypted_attachment][settings_edit_form][settings][modal]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $elements['decrypt'] = [
      '#title' => $this->t('Switch link destination to the decrypt form'),
      '#type' => 'checkbox',
      '#default_value' => $this->getSetting('decrypt'),
      '#states' => [
        'visible' => [
          ':input[name="fields[field_encrypted_attachment][settings_edit_form][settings][link]"]' => ['checked' => TRUE],
        ],
        'unchecked' => [
          ':input[name="fields[field_encrypted_attachment][settings_edit_form][settings][link]"]' => ['checked' => FALSE],
        ],
      ],
    ];

    $elements['modal'] = [
      '#title' => $this->t('Use decrypt modal form'),
      '#type' => 'checkbox',
      '#default_value' => $this->getSetting('modal'),
      '#states' => [
        'visible' => [
          ':input[name="fields[field_encrypted_attachment][settings_edit_form][settings][decrypt]"]' => ['checked' => TRUE],
        ],
        'unchecked' => [
          ':input[name="fields[field_encrypted_attachment][settings_edit_form][settings][decrypt]"]' => ['checked' => FALSE],
        ],
        'disabled' => [
          ':input[name="fields[field_encrypted_attachment][settings_edit_form][settings][new_tab]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = parent::settingsSummary();
    $summary[] = $this->getSetting('decrypt') ? $this->t('Switch link to the decrypt form') : '';
    $summary[] = $this->getSetting('new_tab') ? $this->t('Open in a new tab') : $this->t('Open in current tab');
    $summary[] = $this->getSetting('modal') ? $this->t('Use decrypt modal form') : '';
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    $output_as_link = $this->getSetting('link');

    foreach ($this->getEntitiesToView($items, $langcode) as $delta => $entity) {
      $label = $entity->label();
      // If the link is to be displayed and the entity has a uri, display a
      // link.
      if ($output_as_link && !$entity->isNew()) {
        try {
          $uri = $entity->toUrl();
          // Set link target to Decrypt page.
          if ($this->getSetting('decrypt')) {
            $uri = $entity->toUrl('decrypt');
          }
        }
        catch (UndefinedLinkTemplateException $e) {
          // This exception is thrown by \Drupal\Core\Entity\Entity::urlInfo()
          // and it means that the entity type doesn't have a link template nor
          // a valid "uri_callback", so don't bother trying to output a link for
          // the rest of the referenced entities.
          $output_as_link = FALSE;
        }
      }

      if ($output_as_link && isset($uri) && !$entity->isNew()) {
        if ($this->getSetting('new_tab')) {
          $options = [
            'attributes' => [
              'target' => '_blank',
            ]
          ];
          $uri->MergeOptions($options);
        }

        // Add proc info as data-atributes.
        if ($this->getSetting('modal')) {
          $options = [
            'attributes' => [
              'id' => 'decrypt-' . $items->getName(),
              'data-proc-id' => $entity->id(),
              'data-proc-field-name' => $items->getName(),
              'class' => [
                'proc-attach-dialog',
              ],
              'target' => '',
            ],
          ];
          $uri->MergeOptions($options);
        }

        $elements[$delta] = [
          '#type' => 'link',
          '#title' => $label,
          '#url' => $uri,
          '#options' => $uri->getOptions(),
        ];

        // Attach Proc decrypt dialog and field settings.
        if ($this->getSetting('modal')) {
          $elements[$delta]['#attached']['library'][] = 'proc/proc-decrypt-dialog';
          $elements[$delta]['#attached']['drupalSettings']['proc'][$items->getName()] = [];
          if (
            isset($this->getFieldSettings()['handler'])
            && $this->getFieldSettings()['handler'] == 'default:proc'
            ) {
            $elements[$delta]['#attached']['drupalSettings']['proc'][$items->getName()]['settings'] = $this
              ->getFieldSettings()['handler_settings']['proc'];
          }
        }

        if (!empty($items[$delta]->_attributes)) {
          $elements[$delta]['#options'] += ['attributes' => []];
          $elements[$delta]['#options']['attributes'] += $items[$delta]->_attributes;
          // Unset field item attributes since they have been included in the
          // formatter output and shouldn't be rendered in the field template.
          unset($items[$delta]->_attributes);
        }
      }
      else {
        $elements[$delta] = ['#plain_text' => $label];
      }
      $elements[$delta]['#entity'] = $entity;
      $elements[$delta]['#cache']['tags'] = $entity->getCacheTags();
    }

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity) {
    return parent::checkAccess($entity);
  }

}

==> proc-10.1.26.tar.gz: proc/src/Plugin/Field/FieldFormatter/ProcFieldFormatter.php <==
<?php

namespace Drupal\proc\Plugin\Field\FieldFormatter;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\EntityReferenceLabelFormatter;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'entity reference label' formatter.
 *
 * @FieldFormatter(
 *   id = "proc_entity_reference_label_formatter",
 *   label = @Translation("Label"),
 *   description = @Translation("Display the label of the referenced proc entities."),
 *   field_types = {
 *     "proc_entity_reference_field"
 *   }
 * )
 */
class ProcFieldFormatter extends EntityReferenceLabelFormatter {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'decrypt' => FALSE,
      'new_tab' => TRUE,
      'modal' => FALSE,
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $elements = parent::settingsForm($form, $form_state);

    $elements['new_tab'] = [
      '#title' => $this->t('Open in a new tab'),
      '#type' => 'checkbox',
      '#default_value' => $this->getSetting('new_tab'),
      '#states' => [
        'visible' => [
          ':input[name="fields[' . $this->fieldDefinition->get('field_name') . '][settings_edit_form][settings][link]"]' => ['checked' => TRUE],
        ],
        'disabled' => [
          ':input[name="fields[' . $this->fieldDefinition->get('field_name') . '][settings_edit_form][settings][modal]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $elements['decrypt'] = [
      '#title' => $this->t('Switch link destination to the decrypt form'),
      '#type' => 'checkbox',
      '#default_value' => $this->getSetting('decrypt'),
      '#states' => [
        'visible' => [
          ':input[name="fields[' . $this->fieldDefinition->get('field_name') . '][settings_edit_form][settings][link]"]' => ['checked' => TRUE],
        ],
        'unchecked' => [
          ':input[name="fields[' . $this->fieldDefinition->get('field_name') . '][settings_edit_form][settings][link]"]' => ['checked' => FALSE],
        ],
      ],
    ];

    $elements['modal'] = [
      '#title' => $this->t('Use decrypt modal form'),
      '#type' => 'checkbox',
      '#default_value' => $this->getSetting('modal'),
      '#states' => [
        'visible' => [
          ':input[name="fields[' . $this->fieldDefinition->get('field_name') . '][settings_edit_form][settings][decrypt]"]' => ['checked' => TRUE],
        ],
        'unchecked' => [
          ':input[name="fields[' . $this->fieldDefinition->get('field_name') . '][settings_edit_form][settings][decrypt]"]' => ['checked' => FALSE],
        ],
        'disabled' => [
          ':input[name="fields[' . $this->fieldDefinition->get('field_name') .'][settings_edit_form][settings][new_tab]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = parent::settingsSummary();
    $summary[] = $this->getSetting('decrypt') ? $this->t('Switch link to the decrypt form') : '';
    $summary[] = $this->getSetting('new_tab') ? $this->t('Open in a new tab') : $this->t('Open in current tab');
    $summary[] = $this->getSetting('modal') ? $this->t('Use decrypt modal form') : '';
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    $output_as_link = $this->getSetting('link');

    foreach ($this->getEntitiesToView($items, $langcode) as $delta => $entity) {
      $label = $entity->label();
      // If the link is to be displayed and the entity has a uri, display a
      // link.
      if ($output_as_link && !$entity->isNew()) {
        try {
          $uri = $entity->toUrl();
          // Set link target to Decrypt page.
          if ($this->getSetting('decrypt')) {
            $uri = $entity->toUrl('decrypt');
          }
        }
        catch (UndefinedLinkTemplateException $e) {
          // This exception is thrown by \Drupal\Core\Entity\Entity::urlInfo()
          // and it means that the entity type doesn't have a link template nor
          // a valid "uri_callback", so don't bother trying to output a link for
          // the rest of the referenced entities.
          $output_as_link = FALSE;
        }
      }

      if ($output_as_link && isset($uri) && !$entity->isNew()) {
        if ($this->getSetting('new_tab')) {
          $options = [
            'attributes' => [
              'target' => '_blank',
            ]
          ];
          $uri->MergeOptions($options);
        }

        // Add proc info as data-atributes.
        if ($this->getSetting('modal')) {
          $options = [
            'attributes' => [
              'id' => 'decrypt-' . $items->getName(),
              'data-proc-id' => $entity->id(),
              'data-proc-field-name' => $items->getName(),
              'class' => [
                'proc-attach-dialog',
              ],
              'target' => '',
            ],
          ];
          $uri->MergeOptions($options);
        }

        $elements[$delta] = [
          '#type' => 'link',
          '#title' => $label,
          '#url' => $uri,
          '#options' => $uri->getOptions(),
        ];

        // Attach Proc decrypt dialog and field settings.
        if ($this->getSetting('modal')) {
          $elements[$delta]['#attached']['library'][] = 'proc/proc-decrypt-dialog';
          $elements[$delta]['#attached']['drupalSettings']['proc'][$items->getName()] = [];
          // @todo Send field settings to JS via drupalSettings.
          if (
            $this->getFieldSettings()['handler'] == 'default:proc'
            && isset($this->getFieldSettings()['handler_settings'])
            ) {
            $elements[$delta]['#attached']['drupalSettings']['proc'][$items->getName()]['settings'] = $this
              ->getFieldSettings()['handler_settings'];
          }
        }

        if (!empty($items[$delta]->_attributes)) {
          $elements[$delta]['#options'] += ['attributes' => []];
          $elements[$delta]['#options']['attributes'] += $items[$delta]->_attributes;
          // Unset field item attributes since they have been included in the
          // formatter output and shouldn't be rendered in the field template.
          unset($items[$delta]->_attributes);
        }
      }
      else {
        $elements[$delta] = ['#plain_text' => $label];
      }
      $elements[$delta]['#entity'] = $entity;
      $elements[$delta]['#cache']['tags'] = $entity->getCacheTags();
    }

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity) {
    return parent::checkAccess($entity);
  }

}
